@@ -11,7 +11,7 @@ use URPM::Resolve;
 use URPM::Signature;
 
 our @ISA = qw(DynaLoader);
-our $VERSION = '5.00';
+our $VERSION = '5.15.1';
 
 URPM->bootstrap($VERSION);
 
@@ -188,7 +188,7 @@ sub traverse_tag_find {
 #- this is used when faking a URPM::DB: $urpm can be used as-a $db
 #- (used for urpmi --env)
 sub create_transaction {
-    my ($urpm) = @_;
+    my ($_urpm) = @_; # same args as URPM.xs:create_transaction()
     die "Installing is not supported with a fake environment!";
 }
 
@@ -765,6 +765,8 @@ Just the provided package name.
 
 =item $package->requires()
 
+=item $package->recommends()
+
 Full requires tags
 
 =item $package->requires_nosense()
@@ -866,6 +868,7 @@ It's usually the $urpm object.
 Recognized options are:
 
     callback_close  => sub { ... }
+    callback_elem   => sub { ... }
     callback_error  => sub { ... }
     callback_inst   => sub { ... }
     callback_open   => sub { ... }
@@ -883,15 +886,15 @@ Recognized options are:
 
 They roughly correspond to command-line options to rpm(1).
 
-'callback_open' signature is (C<$data>, C<$cb_type>, C<$pkg_id>). It _must_ return a file handler for the asked package.
+'callback_open' signature is (C<$data>, C<$cb_type>, C<$pkg_id>, C<pkg_name>). It _must_ return a file handler for the asked package.
 
-'callback_close' signature is (C<$data>, C<$cb_type>, C<$pkg_id>). It is called just before URPM close the fd for the installed package.
+'callback_close' signature is (C<$data>, C<$cb_type>, C<$pkg_id>, C<pkg_name>). It is called just before URPM close the fd for the installed package.
 
 C<$cb_type> is one of 'open' or 'close'.
 
-Other Callbacks signature is callback(C<$data>, C<$cb_type>, C<$pkg_id>, C<$subtype>, C<$amout>, C<$total>)
+Other Callbacks signature is callback(C<$data>, C<$cb_type>, C<$pkg_id>, C<$subtype>, C<$amout>, C<$total>, C<pkg_name>)
 
-C<$cb_type> is one of 'error', 'inst', 'trans' or 'uninst'. C<$subtype> can be 'start', 'progress' or 'stop'.
+C<$cb_type> is one of 'elem', 'error', 'inst', 'trans' or 'uninst'. C<$subtype> can be 'start', 'progress' or 'stop'.
 For 'error', it can be 'cpio', 'script' or 'unpack'.
 
 The purpose of those callbacks is to report progress (the two last parameters (C<$amount> & C<$total>) enable to compute progress percentage).
@@ -1049,7 +1052,7 @@ Copyright 2002, 2003, 2004, 2005 MandrakeSoft SA
 
 Copyright 2005, 2006, 2007, 2008 Mandriva SA
 
-Copyright 2011, 2012, 2013 Mageia
+Copyright 2011, 2012, 2013, 2014, 2015, 2016 Mageia
 
 FranE<ccedil>ois Pons (original author), Rafael Garcia-Suarez, Pixel, Thierry Vignaud <tv@mageia.org> (current maintainer)
 
